@@ -104,16 +104,16 @@ class BadNet(Attack):
 
     # ---------------------- I/O ----------------------------- #
 
-    def save(self, **kwargs):
-        filename = self.get_filename(**kwargs)
+    def save(self, filename: str = None, **kwargs):
+        filename = filename if filename is not None else self.get_filename(**kwargs)
         file_path = os.path.join(self.folder_path, filename)
         self.mark.save_npz(file_path + '.npz')
         self.mark.save_img(file_path + '.png')
         self.model.save(file_path + '.pth')
         print('attack results saved at: ', file_path)
 
-    def load(self, **kwargs):
-        filename = self.get_filename(**kwargs)
+    def load(self, filename: str = None, **kwargs):
+        filename = filename if filename is not None else self.get_filename(**kwargs)
         file_path = os.path.join(self.folder_path, filename)
         self.mark.load_npz(file_path + '.npz')
         self.model.load(file_path + '.pth')
