@@ -58,13 +58,13 @@ class IMC_ABS(IMC):
         x = torch.cat(x).numpy()
         y = torch.cat(y).numpy()
         seed_data = {'input': x, 'label': y}
-        seed_path = f'{env["result_dir"]}{self.dataset.name}/{self.name}_{self.seed_num}.npy'
+        seed_path = os.path.join(self.folder_path, f'seed_{self.seed_num}.npy')
         np.save(seed_path, seed_data)
         print('seed data saved at: ', seed_path)
         return seed_data
 
     def load_seed_data(self) -> dict[str, torch.Tensor]:
-        seed_path = f'{env["result_dir"]}{self.dataset.name}/{self.name}_{self.seed_num}.npy'
+        seed_path = os.path.join(self.folder_path, f'seed_{self.seed_num}.npy')
         seed_data: dict[str, torch.Tensor] = {}
         seed_data = np.load(seed_path, allow_pickle=True).item() if os.path.exists(seed_path) \
             else self.save_seed_data()
@@ -76,11 +76,9 @@ class IMC_ABS(IMC):
 
     def sample_neuron(self, _input: torch.Tensor) -> dict[str, torch.Tensor]:
         all_ps: dict[str, torch.Tensor] = {}
-        batch_size = _input.shape[0]
-
         layer_output = self.model.get_all_layer(_input)
         for layer in self.model.get_layer_name():
-            if 'pool' in layer or layer in ['features', 'flatten', 'classifier', 'logits', 'output']:
+            if not layer.startswith('features.') and not layer.startswith('classifier.'):
                 continue
             cur_layer_output: torch.Tensor = layer_output[layer].detach().cpu()  # (batch_size, C, H, W)
             channel_num: int = cur_layer_output.shape[1]  # channels
@@ -105,6 +103,7 @@ class IMC_ABS(IMC):
             # result = self.model.get_layer(h_t.flatten(end_dim=2), layer_input=layer).detach().cpu()
             result = []
             for h in h_t:
+                h: torch.Tensor
                 h = h.to(device=env['device'])
                 result.append(self.model.get_layer(h.flatten(end_dim=1), layer_input=layer).detach().cpu())
             result = torch.cat(result)
