@@ -22,15 +22,29 @@ class ImageSet(Dataset):
     num_classes = 1000
     data_shape = [3, 224, 224]
 
-    def __init__(self, norm_par: dict[str, list[float]] = None,
+    def __init__(self, norm_par: dict[str, list[float]] = {'mean': [0.0], 'std': [1.0], },
                  default_model: str = 'resnetcomp18', **kwargs):
         super().__init__(default_model=default_model, **kwargs)
         self.norm_par: dict[str, list[float]] = norm_par
         self.param_list['imageset'] = ['data_shape', 'norm_par']
 
     @staticmethod
-    def get_transform(**kwargs) -> transforms.ToTensor:
-        return transforms.ToTensor()
+    def get_transform(mode: str) -> transforms.Compose:
+        if mode == 'train':
+            transform = transforms.Compose([
+                transforms.RandomResizedCrop((224, 224)),
+                transforms.RandomHorizontalFlip(),
+                transforms.ToTensor()])
+        else:
+            transform = transforms.Compose([
+                transforms.Resize((256, 256)),
+                transforms.CenterCrop((224, 224)),
+                transforms.ToTensor()])
+            # BiT transform
+            # transform = transforms.Compose([
+            #     transforms.Resize((480, 480)),
+            #     transforms.ToTensor()])
+        return transform
 
     def get_dataloader(self, mode: str = None, dataset: Dataset = None, batch_size: int = None, shuffle: bool = None,
                        num_workers: int = None, pin_memory=True, drop_last=False, **kwargs) -> torch.utils.data.DataLoader:
@@ -50,13 +64,12 @@ class ImageSet(Dataset):
     def get_data(data: tuple[torch.Tensor, torch.Tensor], **kwargs) -> tuple[torch.Tensor, torch.Tensor]:
         return data[0].to(env['device'], non_blocking=True), data[1].to(env['device'], dtype=torch.long, non_blocking=True)
 
-    @classmethod
-    def get_class_to_idx(cls, **kwargs) -> dict[str, int]:
-        if 'class_to_idx' in cls.__dict__.keys():
-            return getattr(cls, 'class_to_idx')
-        return {str(i): i for i in range(cls.num_classes)}
+    def get_class_to_idx(self, **kwargs) -> dict[str, int]:
+        if hasattr(self, 'class_to_idx'):
+            return getattr(self, 'class_to_idx')
+        return {str(i): i for i in range(self.num_classes)}
 
-    def initialize_folder(self, img_type: str = '.jpg', **kwargs):
+    def initialize_folder(self, img_type: str = '.png', **kwargs):
         mode_list: list[str] = ['train', 'valid'] if self.valid_set else ['train']
         class_to_idx = self.get_class_to_idx(**kwargs)
         idx_to_class = {v: k for k, v in class_to_idx.items()}
