@@ -20,6 +20,10 @@ class MNIST(ImageSet):
         datasets.MNIST(root=self.folder_path, train=True, download=True)
         datasets.MNIST(root=self.folder_path, train=False, download=True)
 
+    @staticmethod
+    def get_transform(**kwargs) -> transforms.ToTensor:
+        return transforms.ToTensor()
+
     def get_org_dataset(self, mode, transform: Union[str, object] = 'default', **kwargs):
         if transform == 'default':
             transform = self.get_transform(mode=mode)
