@@ -3,8 +3,6 @@
 from .imagefolder import ImageFolder
 from trojanzoo.utils.param import Module
 
-import torchvision.transforms as transforms
-import numpy as np
 # import os
 # import sys
 # import requests
@@ -22,26 +20,6 @@ class VGGface2(ImageFolder):
     md5 = {'train': '88813c6b15de58afc8fa75ea83361d7f'}
     org_folder_name = {'train': 'train'}
 
-    @staticmethod
-    def get_transform(mode: str) -> transforms.Compose:
-        if mode == 'train':
-            transform = transforms.Compose([
-                transforms.RandomResizedCrop((224, 224)),
-                transforms.RandomHorizontalFlip(),
-                transforms.ToTensor()])
-        else:
-            transform = transforms.Compose([
-                transforms.Resize((256, 256)),
-                transforms.CenterCrop((224, 224)),
-                transforms.ToTensor()])
-        return transform
-
-    def initialize_npz(self, mode_list: list[str] = ['train', 'valid'],
-                       transform: transforms.Compose = transforms.Compose([transforms.Resize((256, 256)),
-                                                                           transforms.Lambda(lambda x: np.array(x))]),
-                       **kwargs):
-        super().initialize_npz(mode_list=mode_list, transform=transform, **kwargs)
-
     # Out-Of-Date
     # def download(self, mode: str = 'train', file_path=None, folder_path=None, file_name=None, file_ext='.tar.gz', **kwargs):
     #     assert mode == 'train'
