@@ -45,7 +45,7 @@ class Watermark:
         group.add_argument('--edge_color', dest='edge_color',
                            help='edge color in watermark image, defaults to \'auto\'.')
         group.add_argument('--mark_path', dest='mark_path',
-                           help='edge color in watermark image, defaults to trojanzoo/data/mark/apple_white.png.')
+                           help='edge color in watermark image, defaults to "trojanzoo/data/mark/square_white.png".')
         group.add_argument('--mark_alpha', dest='mark_alpha', type=float,
                            help='mark transparency, defaults to 0.0.')
         group.add_argument('--mark_height', dest='mark_height', type=int,
